export declare class ParseError extends Error {
    readonly input: string;
    readonly message: string;
    readonly index?: number;
    constructor(input: string, message: string, index?: number);
}
export declare type AddrType = 'ipv4' | 'ipv6';
export declare type AddrFormat = 'v4' | 'auto' | 'v4-mapped' | 'v6';
export interface AddrOpts {
    format?: AddrFormat;
    zeroElide?: boolean;
    zeroPad?: boolean;
}
declare class AddrAttrs {
    ipv4Bare: boolean;
    ipv4Mapped: boolean;
}
export declare class Addr {
    _fields: number[];
    _attrs: AddrAttrs;
    getKind(): AddrType;
    toString(opts: AddrOpts): string;
    compare(b: Addr): number;
    and(val: Addr | string): Addr;
    clone(): Addr;
    not(): Addr;
    or(input: Addr | string): Addr;
    offset(num: number): Addr;
    static toAddr(input: Addr | string): Addr;
    protected static _ip6AddrParse(input: string): Addr;
    private _deriveFormatFromAttrs;
}
export declare class CIDR {
    private readonly _prefix;
    private readonly _addr;
    private readonly _mask;
    constructor(addr: string, prefixLen?: number);
    contains(input: Addr | string): boolean;
    first(): Addr;
    last(): Addr;
    compare(b: CIDR): number;
    prefixLength(format?: AddrFormat): number;
    get address(): Addr;
    toString(opts?: AddrOpts): string;
    private _prefixToAddr;
}
export {};
